@@ -18,7 +18,7 @@
 #include "dialog_utils.h"
 
 // kde includes
-#include <klineedit.h>
+#include <QLineEdit>
 #include <kcombobox.h>
 #include <KLocalizedString>
 
@@ -76,9 +76,6 @@ SelectOperationDialog::SelectOperationDialog(UMLView *parent, UMLClassifier * c,
     mainLayout->addWidget(m_pOpRB, 1, 0);
 
     m_pOpCB = new KComboBox(m_pOpGB);
-#if QT_VERSION < 0x050000
-    m_pOpCB->setCompletionMode(KGlobalSettings::CompletionPopup);
-#endif
     m_pOpCB->setDuplicatesEnabled(false); // only allow one of each type in box
     connect(m_pOpCB, SIGNAL(currentIndexChanged(int)), this, SLOT(slotIndexChanged(int)));
     mainLayout->addWidget(m_pOpCB, 1, 1, 1, 2);
@@ -90,7 +87,7 @@ SelectOperationDialog::SelectOperationDialog(UMLView *parent, UMLClassifier * c,
     m_pCustomRB = new QLabel(i18n("Custom operation:"), m_pOpGB);
     mainLayout->addWidget(m_pCustomRB, 2, 0);
 
-    m_pOpLE = new KLineEdit(m_pOpGB);
+    m_pOpLE = new QLineEdit(m_pOpGB);
     connect(m_pOpLE, SIGNAL(textChanged(QString)), this, SLOT(slotTextChanged(QString)));
     mainLayout->addWidget(m_pOpLE, 2, 1, 1, 2);
     setupOperationsList();
